@@ -15,8 +15,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   see <http://www.gnu.org/licenses/>.
 
    Author: Stef Walter <nielsen@memberwebs.com>
 */
@@ -32,8 +31,58 @@
 
 #include <glib/gi18n-lib.h>
 
+#include <string.h>
+
 EGG_SECURE_DEFINE_GLIB_GLOBALS ();
 
+/**
+ * SECTION:gck-library
+ * @title: Library Utilities
+ * @short_description: Library utilities such as version checks
+ *
+ * Basic library utilities such as version checks.
+ */
+
+/**
+ * GCK_CHECK_VERSION:
+ * @major: the major version to check for
+ * @minor: the minor version to check for
+ * @micro: the micro version to check for
+ *
+ * Checks the version of the Gck libarry that is being compiled
+ * against.
+ *
+ * <example>
+ * <title>Checking the version of the Gck library</title>
+ * <programlisting>
+ * #if !GCK_CHECK_VERSION (3, 0, 0)
+ * #warning Old Gck version, disabling functionality
+ * #endif
+ * </programlisting>
+ * </example>
+ *
+ * Returns: %TRUE if the version of the GLib header files
+ * is the same as or newer than the passed-in version.
+ */
+
+/**
+ * GCK_MAJOR_VERSION:
+ *
+ * The major version number of the Gck library.
+ */
+
+/**
+ * GCK_MINOR_VERSION:
+ *
+ * The minor version number of the Gck library.
+ */
+
+/**
+ * GCK_MICRO_VERSION:
+ *
+ * The micro version number of the Gck library.
+ */
+
 /**
  * SECTION:gck-error
  * @title: Errors
@@ -383,7 +432,7 @@ _gck_ulong_hash (gconstpointer v)
 gboolean
 _gck_ulong_equal (gconstpointer v1, gconstpointer v2)
 {
-	return *((const gulong*)v1) == *((const gulong*)v2);
+	return memcmp(v1, v2, sizeof (gulong)) == 0;
 }
 
 /**
@@ -404,7 +453,7 @@ gck_value_to_ulong (const guchar *value,
 	if (!value || length != sizeof (CK_ULONG))
 		return FALSE;
 	if (result)
-		*result = *((CK_ULONG*)value);
+		memcpy(result, value, sizeof(CK_ULONG));
 	return TRUE;
 }
 
@@ -423,10 +472,13 @@ gck_value_to_boolean (const guchar *value,
                       gsize length,
                       gboolean *result)
 {
+	CK_BBOOL tempval = CK_FALSE;
 	if (!value || length != sizeof (CK_BBOOL))
 		return FALSE;
-	if (result)
-		*result = *((CK_BBOOL*)value) ? TRUE : FALSE;
+	if (result) {
+		memcpy(&tempval, value, sizeof(CK_BBOOL));
+		*result = tempval ? TRUE : FALSE;
+	}
 	return TRUE;
 }
 
