@@ -438,15 +438,17 @@ void
 gck_object_destroy_async (GckObject *self, GCancellable *cancellable,
                            GAsyncReadyCallback callback, gpointer user_data)
 {
+	GckCall *call;
 	Destroy* args;
 
 	g_return_if_fail (GCK_IS_OBJECT (self));
 	g_return_if_fail (GCK_IS_SESSION (self->pv->session));
 
-	args = _gck_call_async_prep (self->pv->session, self, perform_destroy, NULL, sizeof (*args), NULL);
+	call = _gck_call_async_prep (self->pv->session, perform_destroy, NULL, sizeof (*args), NULL);
+	args = _gck_call_get_arguments (call);
 	args->object = self->pv->handle;
 
-	_gck_call_async_ready_go (args, cancellable, callback, user_data);
+	_gck_call_async_ready_go (call, self, cancellable, callback, user_data);
 }
 
 /**
@@ -464,7 +466,7 @@ gboolean
 gck_object_destroy_finish (GckObject *self, GAsyncResult *result, GError **error)
 {
 	g_return_val_if_fail (GCK_IS_OBJECT (self), FALSE);
-	g_return_val_if_fail (GCK_IS_CALL (result), FALSE);
+	g_return_val_if_fail (G_IS_TASK (result), FALSE);
 	return _gck_call_basic_finish (result, error);
 }
 
@@ -553,18 +555,20 @@ void
 gck_object_set_async (GckObject *self, GckAttributes *attrs, GCancellable *cancellable,
                        GAsyncReadyCallback callback, gpointer user_data)
 {
+	GckCall *call;
 	SetAttributes *args;
 
 	g_return_if_fail (GCK_IS_OBJECT (self));
 	g_return_if_fail (attrs != NULL);
 
-	args = _gck_call_async_prep (self->pv->session, self, perform_set_attributes,
+	call = _gck_call_async_prep (self->pv->session, perform_set_attributes,
 	                             NULL, sizeof (*args), free_set_attributes);
 
+	args = _gck_call_get_arguments (call);
 	args->attrs = gck_attributes_ref_sink (attrs);
 	args->object = self->pv->handle;
 
-	_gck_call_async_ready_go (args, cancellable, callback, user_data);
+	_gck_call_async_ready_go (call, self, cancellable, callback, user_data);
 }
 
 /**
@@ -584,11 +588,11 @@ gck_object_set_finish (GckObject *self, GAsyncResult *result, GError **error)
 	SetAttributes *args;
 
 	g_return_val_if_fail (GCK_IS_OBJECT (self), FALSE);
-	g_return_val_if_fail (GCK_IS_CALL (result), FALSE);
+	g_return_val_if_fail (G_IS_TASK (result), FALSE);
 	g_return_val_if_fail (!error || !*error, FALSE);
 
 	/* Unlock the attributes we were using */
-	args = _gck_call_arguments (result, SetAttributes);
+	args = _gck_call_async_result_arguments (result, SetAttributes);
 	g_assert (args->attrs);
 
 	return _gck_call_basic_finish (result, error);
@@ -758,21 +762,23 @@ gck_object_get_async (GckObject *self,
                       GAsyncReadyCallback callback,
                       gpointer user_data)
 {
+	GckCall *call;
 	GetAttributes *args;
 	guint i;
 
 	g_return_if_fail (GCK_IS_OBJECT (self));
 
-	args = _gck_call_async_prep (self->pv->session, self, perform_get_attributes,
+	call = _gck_call_async_prep (self->pv->session, perform_get_attributes,
 	                             NULL, sizeof (*args), free_get_attributes);
 
+	args = _gck_call_get_arguments (call);
 	gck_builder_init (&args->builder);
 	for (i = 0; i < n_attr_types; ++i)
 		gck_builder_add_empty (&args->builder, attr_types[i]);
 
 	args->object = self->pv->handle;
 
-	_gck_call_async_ready_go (args, cancellable, callback, user_data);
+	_gck_call_async_ready_go (call, self, cancellable, callback, user_data);
 }
 
 /**
@@ -795,10 +801,10 @@ gck_object_get_finish (GckObject *self, GAsyncResult *result, GError **error)
 	GetAttributes *args;
 
 	g_return_val_if_fail (GCK_IS_OBJECT (self), NULL);
-	g_return_val_if_fail (GCK_IS_CALL (result), NULL);
+	g_return_val_if_fail (G_IS_TASK (result), NULL);
 	g_return_val_if_fail (!error || !*error, NULL);
 
-	args = _gck_call_arguments (result, GetAttributes);
+	args = _gck_call_async_result_arguments (result, GetAttributes);
 
 	if (!_gck_call_basic_finish (result, error))
 		return NULL;
@@ -960,6 +966,7 @@ gck_object_get_data_async (GckObject *self, gulong attr_type, GckAllocator alloc
                             GCancellable *cancellable, GAsyncReadyCallback callback,
                             gpointer user_data)
 {
+	GckCall *call;
 	GetAttributeData *args;
 
 	g_return_if_fail (GCK_IS_OBJECT (self));
@@ -967,14 +974,15 @@ gck_object_get_data_async (GckObject *self, gulong attr_type, GckAllocator alloc
 	if (!allocator)
 		allocator = g_realloc;
 
-	args = _gck_call_async_prep (self->pv->session, self, perform_get_attribute_data,
+	call = _gck_call_async_prep (self->pv->session, perform_get_attribute_data,
 	                             NULL, sizeof (*args), free_get_attribute_data);
 
+	args = _gck_call_get_arguments (call);
 	args->allocator = allocator;
 	args->object = self->pv->handle;
 	args->type = attr_type;
 
-	_gck_call_async_ready_go (args, cancellable, callback, user_data);
+	_gck_call_async_ready_go (call, self, cancellable, callback, user_data);
 }
 
 /**
@@ -1001,14 +1009,14 @@ gck_object_get_data_finish (GckObject *self,
 	guchar *data;
 
 	g_return_val_if_fail (GCK_IS_OBJECT (self), NULL);
-	g_return_val_if_fail (GCK_IS_CALL (result), NULL);
+	g_return_val_if_fail (G_IS_TASK (result), NULL);
 	g_return_val_if_fail (n_data, NULL);
 	g_return_val_if_fail (!error || !*error, NULL);
 
 	if (!_gck_call_basic_finish (result, error))
 		return NULL;
 
-	args = _gck_call_arguments (result, GetAttributeData);
+	args = _gck_call_async_result_arguments (result, GetAttributeData);
 
 	*n_data = args->n_result;
 	data = args->result;
@@ -1114,19 +1122,21 @@ gck_object_set_template_async (GckObject *self, gulong attr_type, GckAttributes
                                 GCancellable *cancellable, GAsyncReadyCallback callback,
                                 gpointer user_data)
 {
+	GckCall *call;
 	set_template_args *args;
 
 	g_return_if_fail (GCK_IS_OBJECT (self));
 	g_return_if_fail (attrs);
 
-	args = _gck_call_async_prep (self->pv->session, self, perform_set_template,
+	call = _gck_call_async_prep (self->pv->session, perform_set_template,
 	                             NULL, sizeof (*args), free_set_template);
 
+	args = _gck_call_get_arguments (call);
 	args->attrs = gck_attributes_ref_sink (attrs);
 	args->type = attr_type;
 	args->object = self->pv->handle;
 
-	_gck_call_async_ready_go (args, cancellable, callback, user_data);
+	_gck_call_async_ready_go (call, self, cancellable, callback, user_data);
 }
 
 /**
@@ -1146,11 +1156,11 @@ gck_object_set_template_finish (GckObject *self, GAsyncResult *result, GError **
 	set_template_args *args;
 
 	g_return_val_if_fail (GCK_IS_OBJECT (self), FALSE);
-	g_return_val_if_fail (GCK_IS_CALL (result), FALSE);
+	g_return_val_if_fail (G_IS_TASK (result), FALSE);
 	g_return_val_if_fail (!error || !*error, FALSE);
 
 	/* Unlock the attributes we were using */
-	args = _gck_call_arguments (result, set_template_args);
+	args = _gck_call_async_result_arguments (result, set_template_args);
 	g_assert (args->attrs);
 
 	return _gck_call_basic_finish (result, error);
@@ -1272,17 +1282,19 @@ gck_object_get_template_async (GckObject *self, gulong attr_type,
                                 GCancellable *cancellable, GAsyncReadyCallback callback,
                                 gpointer user_data)
 {
+	GckCall *call;
 	get_template_args *args;
 
 	g_return_if_fail (GCK_IS_OBJECT (self));
 
-	args = _gck_call_async_prep (self->pv->session, self, perform_get_template,
+	call = _gck_call_async_prep (self->pv->session, perform_get_template,
 	                             NULL, sizeof (*args), free_get_template);
 
+	args = _gck_call_get_arguments (call);
 	args->object = self->pv->handle;
 	args->type = attr_type;
 
-	_gck_call_async_ready_go (args, cancellable, callback, user_data);
+	_gck_call_async_ready_go (call, self, cancellable, callback, user_data);
 }
 
 /**
@@ -1304,12 +1316,12 @@ gck_object_get_template_finish (GckObject *self, GAsyncResult *result,
 	get_template_args *args;
 
 	g_return_val_if_fail (GCK_IS_OBJECT (self), NULL);
-	g_return_val_if_fail (GCK_IS_CALL (result), NULL);
+	g_return_val_if_fail (G_IS_TASK (result), NULL);
 	g_return_val_if_fail (!error || !*error, NULL);
 
 	if (!_gck_call_basic_finish (result, error))
 		return NULL;
 
-	args = _gck_call_arguments (result, get_template_args);
+	args = _gck_call_async_result_arguments (result, get_template_args);
 	return gck_attributes_ref_sink (gck_builder_end (&args->builder));
 }
