@@ -96,8 +96,9 @@ gcr_importer_default_init (GcrImporterIface *iface)
 		 * The label for the importer.
 		 */
 		g_object_interface_install_property (iface,
-		         g_param_spec_string ("label", "Label", "The label for the importer",
-		                              "", G_PARAM_READABLE));
+			g_param_spec_string ("label", "Label", "The label for the importer",
+			                     "",
+			                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 		/**
 		 * GcrImporter:icon:
@@ -105,8 +106,9 @@ gcr_importer_default_init (GcrImporterIface *iface)
 		 * The icon for the importer.
 		 */
 		g_object_interface_install_property (iface,
-		         g_param_spec_object ("icon", "Icon", "The icon for the importer",
-		                              G_TYPE_ICON, G_PARAM_READABLE));
+			g_param_spec_object ("icon", "Icon", "The icon for the importer",
+			                     G_TYPE_ICON,
+			                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 		/**
 		 * GcrImporter:interaction:
@@ -114,9 +116,10 @@ gcr_importer_default_init (GcrImporterIface *iface)
 		 * The interaction for the importer.
 		 */
 		g_object_interface_install_property (iface,
-		         g_param_spec_object ("interaction", "Interaction",
-		                              "Interaction for prompts",
-		                              G_TYPE_TLS_INTERACTION, G_PARAM_READWRITE));
+			g_param_spec_object ("interaction", "Interaction",
+			                     "Interaction for prompts",
+			                     G_TYPE_TLS_INTERACTION,
+			                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 		/**
 		 * GcrImporter:uri:
@@ -124,8 +127,9 @@ gcr_importer_default_init (GcrImporterIface *iface)
 		 * The URI of the location imported to.
 		 */
 		g_object_interface_install_property (iface,
-		                g_param_spec_string ("uri", "URI", "URI of location",
-		                                     NULL, G_PARAM_READABLE));
+			g_param_spec_string ("uri", "URI", "URI of location",
+			                     NULL,
+			                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 		g_once_init_leave (&initialized, 1);
 	}
@@ -505,7 +509,7 @@ gcr_importer_import_finish (GcrImporter *importer,
  * Get the interaction used to prompt the user when needed by this
  * importer.
  *
- * Returns: (transfer none) (allow-none): the interaction or %NULL
+ * Returns: (transfer none) (nullable): the interaction or %NULL
  */
 GTlsInteraction *
 gcr_importer_get_interaction (GcrImporter *importer)
