@@ -117,11 +117,13 @@ gcr_failure_renderer_class_init (GcrFailureRendererClass *klass)
 
 	g_object_class_install_property (gobject_class, PROP_LABEL,
 	           g_param_spec_string ("label", "Label", "Failure Label",
-	                                "", G_PARAM_READWRITE));
+	                                "",
+	                                G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	g_object_class_install_property (gobject_class, PROP_ATTRIBUTES,
 	           g_param_spec_boxed ("attributes", "Attributes", "Renderer attributes",
-	                               GCK_TYPE_ATTRIBUTES, G_PARAM_READWRITE));
+	                               GCK_TYPE_ATTRIBUTES,
+	                               G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -175,7 +177,7 @@ gcr_renderer_iface_init (GcrRendererIface *iface)
 
 /**
  * gcr_failure_renderer_new:
- * @label: (allow-none): the label for the failure
+ * @label: (nullable): the label for the failure
  * @error: the error to display
  *
  * Create a new renderer for an error.
