@@ -168,7 +168,8 @@ gcr_key_widget_class_init (GcrKeyWidgetClass *klass)
 
 	g_object_class_install_property (gobject_class, PROP_ATTRIBUTES,
 	         g_param_spec_boxed ("attributes", "Attributes", "The data displayed in the widget",
-	                             GCK_TYPE_ATTRIBUTES, G_PARAM_READWRITE));
+	                             GCK_TYPE_ATTRIBUTES,
+	                             G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 }
 
 /* -----------------------------------------------------------------------------
@@ -177,7 +178,7 @@ gcr_key_widget_class_init (GcrKeyWidgetClass *klass)
 
 /**
  * gcr_key_widget_new:
- * @attrs: (allow-none): key to display, or %NULL
+ * @attrs: (nullable): key to display, or %NULL
  *
  * Create a new key widget which displays a given key in the attributes.
  *
@@ -193,7 +194,7 @@ gcr_key_widget_new (GckAttributes *attrs)
 /**
  * gcr_key_widget_set_attributes:
  * @self: The key widget
- * @attrs: (allow-none): the attributes to display
+ * @attrs: (nullable): the attributes to display
  *
  * Get the attributes displayed in the widget. The attributes should represent
  * either an RSA, DSA or EC key in PKCS\#11 style.
@@ -211,7 +212,7 @@ gcr_key_widget_set_attributes (GcrKeyWidget *self, GckAttributes *attrs)
  *
  * Get the attributes displayed in the widget.
  *
- * Returns: (allow-none) (transfer none): The attributes, owned by the widget.
+ * Returns: (nullable) (transfer none): The attributes, owned by the widget.
  */
 GckAttributes*
 gcr_key_widget_get_attributes (GcrKeyWidget *self)
