@@ -27,8 +27,6 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <gdk/gdkx.h>
-#include <pango/pango.h>
 
 #include <locale.h>
 #include <stdlib.h>
