@@ -263,7 +263,8 @@ gcr_tree_selector_class_init (GcrTreeSelectorClass *klass)
 	 */
 	g_object_class_install_property (gobject_class, PROP_COLLECTION,
 	           g_param_spec_object ("collection", "Collection", "Collection to select from",
-	                                GCR_TYPE_COLLECTION, G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+	                                GCR_TYPE_COLLECTION,
+	                                G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GcrTreeSelector:columns:
@@ -272,7 +273,7 @@ gcr_tree_selector_class_init (GcrTreeSelectorClass *klass)
 	 */
 	g_object_class_install_property (gobject_class, PROP_COLUMNS,
 	           g_param_spec_pointer ("columns", "Columns", "Columns to display in selector",
-	                                 G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+	                                 G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
 }
 
 /* -----------------------------------------------------------------------------
